#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// 
    /// </summary>
    [Description("")]
    public class SampleSecondarySeriesAsInputSeries : Indicator
    {
		private SMA sma1;
		private SMA sma2;
		
        protected override void Initialize()
        {
			Add(PeriodType.Minute, 5);
            Add(new Plot(Color.Blue, PlotStyle.Line, "SMA Primary Series"));
			Add(new Plot(Color.Green, PlotStyle.Line, "SMA Secondary Series"));
            Overlay				= true;
        }
		
		protected override void OnStartUp()
		{
			sma1 = SMA(BarsArray[0], 14);
			sma2 = SMA(BarsArray[1], 14);
		}
		
        protected override void OnBarUpdate()
        {
			// ensure both series have at least one bar
			if (CurrentBars[0] < 1 || CurrentBars[1] < 1)
				return;			
			
			// when the 5 minute series is processing set the secondary plot to the sma with the secondary series input
			if (BarsInProgress == 1)
				SMASecondary[0] = sma2[0];
			
			// when the primary series is processing set the primary plot to the sma with the primary series input
			if (BarsInProgress == 0)
			{
				SMAPrimary[0] = sma1[0];
				
				// if the secondary 5 minute series did not close, set the current bar's value to the previous bar's value to prevent gaps 
				if (!SMASecondary.ContainsValue(0))
					SMASecondary[0] = SMASecondary[1];
			}
        }

        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries SMAPrimary
        {
            get { return Values[0]; }
        }
		
		[Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries SMASecondary
        {
            get { return Values[1]; }
        }
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private SampleSecondarySeriesAsInputSeries[] cacheSampleSecondarySeriesAsInputSeries = null;

        private static SampleSecondarySeriesAsInputSeries checkSampleSecondarySeriesAsInputSeries = new SampleSecondarySeriesAsInputSeries();

        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        public SampleSecondarySeriesAsInputSeries SampleSecondarySeriesAsInputSeries()
        {
            return SampleSecondarySeriesAsInputSeries(Input);
        }

        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        public SampleSecondarySeriesAsInputSeries SampleSecondarySeriesAsInputSeries(Data.IDataSeries input)
        {
            if (cacheSampleSecondarySeriesAsInputSeries != null)
                for (int idx = 0; idx < cacheSampleSecondarySeriesAsInputSeries.Length; idx++)
                    if (cacheSampleSecondarySeriesAsInputSeries[idx].EqualsInput(input))
                        return cacheSampleSecondarySeriesAsInputSeries[idx];

            lock (checkSampleSecondarySeriesAsInputSeries)
            {
                if (cacheSampleSecondarySeriesAsInputSeries != null)
                    for (int idx = 0; idx < cacheSampleSecondarySeriesAsInputSeries.Length; idx++)
                        if (cacheSampleSecondarySeriesAsInputSeries[idx].EqualsInput(input))
                            return cacheSampleSecondarySeriesAsInputSeries[idx];

                SampleSecondarySeriesAsInputSeries indicator = new SampleSecondarySeriesAsInputSeries();
                indicator.BarsRequired = BarsRequired;
                indicator.CalculateOnBarClose = CalculateOnBarClose;
#if NT7
                indicator.ForceMaximumBarsLookBack256 = ForceMaximumBarsLookBack256;
                indicator.MaximumBarsLookBack = MaximumBarsLookBack;
#endif
                indicator.Input = input;
                Indicators.Add(indicator);
                indicator.SetUp();

                SampleSecondarySeriesAsInputSeries[] tmp = new SampleSecondarySeriesAsInputSeries[cacheSampleSecondarySeriesAsInputSeries == null ? 1 : cacheSampleSecondarySeriesAsInputSeries.Length + 1];
                if (cacheSampleSecondarySeriesAsInputSeries != null)
                    cacheSampleSecondarySeriesAsInputSeries.CopyTo(tmp, 0);
                tmp[tmp.Length - 1] = indicator;
                cacheSampleSecondarySeriesAsInputSeries = tmp;
                return indicator;
            }
        }
    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.SampleSecondarySeriesAsInputSeries SampleSecondarySeriesAsInputSeries()
        {
            return _indicator.SampleSecondarySeriesAsInputSeries(Input);
        }

        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        public Indicator.SampleSecondarySeriesAsInputSeries SampleSecondarySeriesAsInputSeries(Data.IDataSeries input)
        {
            return _indicator.SampleSecondarySeriesAsInputSeries(input);
        }
    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.SampleSecondarySeriesAsInputSeries SampleSecondarySeriesAsInputSeries()
        {
            return _indicator.SampleSecondarySeriesAsInputSeries(Input);
        }

        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        public Indicator.SampleSecondarySeriesAsInputSeries SampleSecondarySeriesAsInputSeries(Data.IDataSeries input)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.SampleSecondarySeriesAsInputSeries(input);
        }
    }
}
#endregion
